@@ -1,3 +1,4 @@
+from datetime import datetime, timedelta
 import time
 import unittest
 from collections import OrderedDict
@@ -10,7 +11,7 @@ import cloudinary
 from cloudinary import api, uploader, utils
 from test.helper_test import SUFFIX, TEST_IMAGE, get_uri, get_params, get_list_param, get_param, TEST_DOC, get_method, \
     UNIQUE_TAG, api_response_mock, ignore_exception, cleanup_test_resources_by_tag, cleanup_test_transformation, \
-    cleanup_test_resources, UNIQUE_TEST_FOLDER
+    cleanup_test_resources, UNIQUE_TEST_FOLDER, EVAL_STR, get_json_body
 from cloudinary.exceptions import BadRequest, NotFound
 
 MOCK_RESPONSE = api_response_mock()
@@ -75,6 +76,27 @@ class ApiTest(unittest.TestCase):
         with ignore_exception(suppress_traceback_classes=(NotFound,)):
             api.delete_upload_mapping(MAPPING_TEST_ID)
 
+    def assert_usage_result(self, usage_api_response):
+        """Asserts that a given object fits the generic structure of the usage API response
+
+        See: `Sample response of usage API <https://cloudinary.com/documentation/admin_api#sample_response-37>`_
+
+        :param usage_api_response:  The response from usage API
+        """
+        keys = ["plan",
+                "last_updated",
+                "transformations",
+                "objects",
+                "bandwidth",
+                "storage",
+                "requests",
+                "resources",
+                "derived_resources",
+                "media_limits"]
+
+        for key in keys:
+            self.assertIn(key, usage_api_response)
+
     def test_http_connector(self):
         """ should create proper http connector in case api_proxy is set  """
         cert_kwargs = {
@@ -230,7 +252,20 @@ class ApiTest(unittest.TestCase):
         api.resource(API_TEST_ID, derived_next_cursor=NEXT_CURSOR)
         args, kwargs = mocker.call_args
         self.assertTrue("derived_next_cursor" in get_params(args))
-    
+
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test07c_resource_allows_versions(self, mocker):
+        """ should allow versions parameter """
+        mocker.return_value = MOCK_RESPONSE
+
+        api.resource(API_TEST_ID, versions=True)
+
+        params = get_params(mocker.call_args[0])
+
+        self.assertIn("versions", params)
+        self.assertTrue(params["versions"])
+
     @patch('urllib3.request.RequestMethods.request')
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test08_delete_derived(self, mocker):
@@ -494,7 +529,25 @@ class ApiTest(unittest.TestCase):
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test18_usage(self):
         """ should support usage API """
-        self.assertIn("last_updated", api.usage())
+        self.assert_usage_result(api.usage())
+
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test18a_usage_by_date(self):
+        """ Should return usage values for a specific date """
+        yesterday = datetime.now() - timedelta(1)
+
+        result_1 = api.usage(date=yesterday)
+        self.assert_usage_result(result_1)
+
+        result_2 = api.usage(date=utils.encode_date_to_usage_api_format(yesterday))
+        self.assert_usage_result(result_2)
+
+        # Verify that the structure of the response is of a single day
+        self.assertNotIn("limit", result_1["bandwidth"])
+        self.assertNotIn("used_percent", result_1["bandwidth"])
+
+        self.assertNotIn("limit", result_2["bandwidth"])
+        self.assertNotIn("used_percent", result_2["bandwidth"])
 
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     @unittest.skip("Skip delete all derived resources by default")
@@ -587,7 +640,8 @@ class ApiTest(unittest.TestCase):
         """ should allow creating upload_presets """
         mocker.return_value = MOCK_RESPONSE
 
-        api.create_upload_preset(name=API_TEST_PRESET, folder="folder", live=True)
+        api.create_upload_preset(name=API_TEST_PRESET, folder="folder", live=True,
+                                 eval=EVAL_STR)
 
         args, kargs = mocker.call_args
 
@@ -596,6 +650,7 @@ class ApiTest(unittest.TestCase):
         self.assertEqual(get_param(mocker, "name"), API_TEST_PRESET)
         self.assertEqual(get_param(mocker, "folder"), "folder")
         self.assertTrue(get_param(mocker, "live"))
+        self.assertEqual(EVAL_STR, get_param(mocker, "eval"))
 
     @patch('urllib3.request.RequestMethods.request')
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
@@ -638,7 +693,8 @@ class ApiTest(unittest.TestCase):
     def test31_update_upload_presets(self, mocker):
         """ should allow getting a single upload_preset """
         mocker.return_value = MOCK_RESPONSE
-        api.update_upload_preset(API_TEST_PRESET, colors=True, unsigned=True, disallow_public_id=True, live=True)
+        api.update_upload_preset(API_TEST_PRESET, colors=True, unsigned=True, disallow_public_id=True, live=True,
+                                 eval=EVAL_STR)
         args, kargs = mocker.call_args
         self.assertEqual(args[0], 'PUT')
         self.assertTrue(get_uri(args).endswith('/upload_presets/{}'.format(API_TEST_PRESET)))
@@ -646,6 +702,7 @@ class ApiTest(unittest.TestCase):
         self.assertTrue(get_params(args)['unsigned'])
         self.assertTrue(get_params(args)['disallow_public_id'])
         self.assertTrue(get_params(args)['live'])
+        self.assertEqual(EVAL_STR, get_param(mocker, "eval"))
 
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test32_background_removal(self):
@@ -753,6 +810,21 @@ class ApiTest(unittest.TestCase):
         self.assertNotEqual(resource, None)
         self.assertEqual(resource["bytes"], 3381)
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test_restore_versions(self, mocker):
+        mocker.return_value = MOCK_RESPONSE
+
+        public_ids = ["pub1", "pub2"]
+        versions = ["ver1", "ver2"]
+
+        api.restore(public_ids, versions=versions)
+
+        json_body = get_json_body(mocker)
+
+        self.assertListEqual(public_ids, json_body["public_ids"])
+        self.assertListEqual(versions, json_body["versions"])
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test_upload_mapping(self):
 
@@ -823,6 +895,17 @@ class ApiTest(unittest.TestCase):
 
         self.assertIn("cinemagraph_analysis", params)
 
+    @patch('urllib3.request.RequestMethods.request')
+    def test_accessibility_analysis_resource(self, mocker):
+        """ should allow the user to pass accessibility_analysis in the resource function """
+        mocker.return_value = MOCK_RESPONSE
+
+        api.resource(API_TEST_ID, accessibility_analysis=True)
+
+        params = get_params(mocker.call_args[0])
+
+        self.assertIn("accessibility_analysis", params)
+
     @patch('urllib3.request.RequestMethods.request')
     def test_api_url_escapes_special_characters(self, mocker):
         """ should escape special characters in api url """
